pub struct StreamResponse<S> {
pub metadata_prelude: MetadataPrelude,
pub stream: S,
}Expand description
A streaming response that contains the metadata prelude and the stream of bytes that will be sent to the client.
Fields
metadata_prelude: MetadataPreludeThe metadata prelude.
stream: SThe stream of bytes that will be sent to the client.